==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/uk/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Assets assigned to :name',
    'bulk_update_warn'	=> 'You are about to edit the properties of :user_count users. Please note that you cannot change your own user attributes using this form, and must make edits to your own user individually.',
    'bulk_update_help'	=> 'This form allows you to update multiple users at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged.',
    'current_assets'    => 'Assets currently checked out to this user',
    'clone'             => 'Клонувати користувача',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Редагувати користувача',
    'filetype_info'     => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'History for :name',
	'info'				=> 'Інфо',
    'restore_user'		=> 'Click here to restore them.',
    'last_login'        => 'Останній вхід',
    'ldap_config_text'  => 'LDAP configuration settings can be found Admin > Settings. The (optional) selected location will be set for all imported users.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'View User :name',
    'usercsv'           => 'Файл CSV',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA Device Enrolled ',
    'two_factor_active'   => '2FA Active ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/uk/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Assets assigned to :name',
    'bulk_update_warn'	=> 'You are about to edit the properties of :user_count users. Please note that you cannot change your own user attributes using this form, and must make edits to your own user individually.',
    'bulk_update_help'	=> 'This form allows you to update multiple users at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged.',
    'current_assets'    => 'Assets currently checked out to this user',
    'clone'             => 'Клонувати користувача',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Редагувати користувача',
    'filetype_info'     => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'History for :name',
    'info'				=> 'Інфо',
    'restore_user'		=> 'Click here to restore them.',
    'last_login'        => 'Останній вхід',
    'ldap_config_text'  => 'LDAP configuration settings can be found Admin > Settings. The (optional) selected location will be set for all imported users.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'View User :name',
    'usercsv'           => 'Файл CSV',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA Device Enrolled',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
